# JAKT
Jakt is just another (k)ommand-line timetracker tool. 

## The name
The name comes from the norwegian word for hunt. Timetracking is one of the best tools in your arsenal in your hunt for productivity.  
And if you are wondering, yes, I started with the acronym. 

## Features
TODO: Features

## Requirements
TODO: Requirements

## Installation

### From Source
1. Clone the repo
2. `cd jakt` 
3. `pip install -e .`  
	Make sure to use the correct version of pip, some users will need to use `pip3` instead. 


## License 
This project is licensed under the MIT License. See [LICENSE](https://github.com/kwillno/jakt/blob/main/LICENSE). 
